#!/etc/opt/openit/perl -w

my $cfg = "/var/opt/openit/etc/acc_types";
my $old = "/var/opt/openit/etc/acc_types.old";
my $new = "/var/opt/openit/etc/acc_types.new";

open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
open(IN, "<$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";

# Lines before LSF Batch jobs
while(my $line = <IN>) {
    if($line =~ /LSF.*Batch/) {
	last;
    }
    print OUT $line;
}

print OUT <<EOF
 (LSF^(Batch^jobs),
  ((Count,Job^Count,x,SUM),
   (Time^in^queue,Time^in^queue^in^minutes,Min,SUM),
   (System^time,System^time^in^minutes,Min,SUM),
   (User^time,User^time^in^minutes,Min,SUM),
   (CPU^time,System^time^+^User^time^in^minutes,Min,SUM),
   (CPU^cost,CPU^time^in^seconds*^CPU^factor,x,SUM)
   (Block^I,Block^I^is^number^of^block^input^operations,x,SUM),
   (Block^O,Block^O^is^number^of^block^output^operations,x,SUM),
   (Block^I/O,Block^I/O^is^sum^of^block^input^+^output^operations,x,SUM)
   (Max^RSS,Maximum^resident^memory^usage^in^KB,x,MAX),
   (Max^VM,Maximum^virtual^memory^usage^in^KB,x,MAX),
   (Elapsed^time,Elapsed^time^in^minutes,Min,SUM),
   (Total^time,Time^in^queue^+^elapsed^time^in^minutes,Min,SUM)),
  (Project,
   User,
   Queue^name,
   Job^status,
   Command,
   Exit^status,
   Execution^host,
   Domain,
   Number^of^exec.^CPUs,
   Number^of^exec.^hosts)),

EOF
;

# Ignore old lines
while(my $line = <IN>) {
    if($line =~ /VMstat/) {
	print OUT $line;	
	last;
    }
    next;
}

# Keep rest of file 
while(my $line = <IN>){
    print OUT $line;
}

close(IN);
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

chmod(0644, $cfg);

exit 0;
